clc
clear all

global b rho_w rho_f sigma g musq kappa lambda_w T R gSub

options=optimset('Display','off','MaxFunEvals',200,'MaxIter',500,'Algorithm','levenberg-marquardt','TolFun',.000000001,'TolX',.000000001);

%  Shocks

rho_fShock=	0.09/12;
rho_wShock=0;%.09/12;

%  Sources of backloading

%gs=0:0.01/12:sigma+rho_f -0.01/12;  %  a variety of personal productivity
%growth rates
gs=0;%0.04/12;  %  Personal prod growth with tenure
%T=3;%  Training cost of 3 months of productivity
T=0;  % no training cost
R= 0.0;%2;  %  Government subsidy flow value
gSub= 0.04/12;  %  Growth of gov subsidy

%  Parameters

sigma=0.035;  %  	separation hazard		
b=0.4; %	flow value of unemployment	
rho_f=	0.06/12;  %  	firm's monthly discount rate
rho_w=	0.06/12;  %  	worker's monthly discount rate	
rho_fBase=rho_f;
rho_wBase=rho_w;
lambda_wCal=0.57;  %	jobfinding rate	at calibration point
lambda_f=1.19;  %  vacancy yield at calibration point
musq= lambda_f*lambda_wCal; %  squared	matching efficiency	

%  Starting values for calibration

U = 0.9/rho_w;
V=sigma*U/(sigma+rho_w);
W=0.95/rho_w;
unkStart=[U;V;W];

Results=[];
D=[];
unkCalStart=unkStart;
Cal=[];

for g=gs %  growth rate of productivity with tenure
    
    %  Calibration
    
    rho_f=rho_fBase;
    rho_w=rho_wBase;
    lambda_w=lambda_wCal;
    checkCal=CalFunc2(unkCalStart);
    [unkCal,discs]=fsolve(@CalFunc2,unkCalStart,options);
    unkCalStart=unkCal;
    P=-T+1/(rho_f-g+sigma);
    U=unkCal(1);
    V=unkCal(2);
    W=unkCal(3);
    J=P-W;
    kappa=lambda_f*J;
    Cal=[Cal,[unkCal;P;J;kappa]];
    
    %  Solution 
    
    unkStart=[U;J;W;lambda_w;V];
    discCal=Func(unkStart);
    [unk,discs]=fsolve(@Func,unkStart,options);
    D=[D,[discCal;discs]];
    accPrev=std(discs);
    
    P=-T+1/(rho_f-g+sigma);
    U=unk(1);
    J=unk(2);
    W=unk(3);
    lambda_w=unk(4);
    V=unk(5);
    u=sigma/(sigma+lambda_w);
    unkPrev=[unk;P;u;g];
    
    %  Higher discounts
    
    unkStart=unkPrev(1:5);
    
    Nsneak=10;
    for frac=0:1/Nsneak:1
        rho_f=rho_fBase+frac*rho_fShock;
        rho_w=rho_wBase+frac*rho_wShock;
        [unk,discs]=fsolve(@Func,unkStart,options);
        acc=std(discs);
        lambda_w=unk(4);
        V=unk(5);
        P=-T+1/(rho_f-g+sigma);
        u=sigma/(sigma+lambda_w);
        unkStart=unk;
        unk=[unk;P;u;g];
    end
   Results=[Results,[unkPrev;unk;rho_f;rho_w;accPrev;acc]];
end  %  g




